==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/ru.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Вы включили двухфакторную аутентификацию с использованием TOTP",
    "You disabled TOTP two-factor authentication for your account" : "Вы отключили двухфакторную аутентификацию TOTP",
    "TOTP two-factor authentication disabled by an admin" : "Двухфакторная аутентификация TOTP была отключена администратором",
    "TOTP (Authenticator app)" : "TOTP (Приложение аутентификации)",
    "Authenticate with a TOTP app" : "Аутентифицируйтесь с помощью TOTP приложения",
    "Two-Factor TOTP Provider" : "Второй фактор — коды TOTP",
    "TOTP two-factor provider" : "Провайдер двухфакторной аутентификации TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Провайдер двухфакторной аутентификации для TOTP (RFC 6238)",
    "Enable TOTP" : "Включить TOTP",
    "Could not enable TOTP" : "Не удалось включить TOTP",
    "Could not verify your key. Please try again" : "Не удаётся проверить ваш ключ. Попробуйте ещё раз.",
    "Your new TOTP secret is:" : "Новый секрет TOTP:",
    "For quick setup, scan this QR code with your TOTP app:" : "Для быстрой настройки, отсканируйте QR-код с помощью приложения TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "После настройки приложения введите проверочный код в поле ниже:",
    "Authentication code" : "Код аутентификации",
    "Verify" : "Подтвердить",
    "Get the authentication code from the two-factor authentication app on your device." : "Введите одноразовый код из приложения двухфакторной аутентификации.",
    "Submit" : "Отправить"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-32.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/ru.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Вы включили двухфакторную аутентификацию с использованием TOTP",
    "You disabled TOTP two-factor authentication for your account" : "Вы отключили двухфакторную аутентификацию TOTP",
    "TOTP two-factor authentication disabled by the administration" : "Двухфакторная TOTP аутентификация была отключена администратором",
    "TOTP (Authenticator app)" : "TOTP (Приложение аутентификации)",
    "Authenticate with a TOTP app" : "Аутентифицируйтесь с помощью TOTP приложения",
    "Two-Factor TOTP Provider" : "Второй фактор — коды TOTP",
    "Could not enable TOTP" : "Не удалось включить TOTP",
    "Could not verify your key. Please try again" : "Не удаётся проверить ваш ключ. Попробуйте ещё раз.",
    "Enable TOTP" : "Включить TOTP",
    "Your new TOTP secret is:" : "Новый секрет TOTP:",
    "For quick setup, scan this QR code with your TOTP app:" : "Для быстрой настройки, отсканируйте QR-код с помощью приложения TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "После настройки приложения введите проверочный код в поле ниже:",
    "Authentication code" : "Код аутентификации",
    "Verify" : "Подтвердить",
    "Get the authentication code from the two-factor authentication app on your device." : "Введите одноразовый код из приложения двухфакторной аутентификации.",
    "Submit" : "Отправить"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
